@@ -3,6 +3,7 @@ from pushgateway.webthing import WebthingProperty
 from pushgateway.openhab import OpenhabItem
 import time
 import threading
+import logging
 
 
 class WebThingPropertyToOpenhabItemLink:
@@ -21,14 +22,10 @@ class WebThingPropertyToOpenhabItemLink:
                 # listen for values to forwards
                 stream = self.webthing_property.new_change_listener(self.__on_changed_callback)
                 stream.start()
-
-                # set initial state (if changes are coming sporadically)
-                self.openhab_item.state = self.__convert(self.webthing_property.property)
-
                 time.sleep(10 * 60)
                 stream.stop()
             except Exception as e:
-                print("error occurred for webthing " + self.webthing_property.name + ": "+ str(e))
+                logging.error("error occurred for webthing " + self.webthing_property.metadata.name + ": "+ str(e))
                 time.sleep(10)
 
     def __on_changed_callback(self, new_value):
@@ -38,7 +35,7 @@ class WebThingPropertyToOpenhabItemLink:
             self.openhab_item.state = item_value
 
     def __convert(self, property_value):
-        if self.webthing_property.type == 'boolean':
+        if self.webthing_property.metadata.type == 'boolean':
             if property_value:
                 return "ON"
             else:
@@ -64,14 +61,10 @@ class OpenhabItemToWebThingPropertyLink:
                 # listen for values to forwards
                 stream = self.openhab_item.new_change_listener(self.__on_changed_callback)
                 stream.start()
-
-                # set initial state (if changes are coming sporadically)
-                self.webthing_property.property = self.__convert(self.openhab_item.state)
-
                 time.sleep(10 * 60)
                 stream.stop()
             except Exception as e:
-                print("error occurred for openhab " + self.webthing_property.name + ": "+ str(e))
+                logging.error("error occurred for openhab " + self.webthing_property.metadata.name + ": "+ str(e))
                 time.sleep(10)
 
     def __on_changed_callback(self, new_value):
@@ -81,8 +74,8 @@ class OpenhabItemToWebThingPropertyLink:
             self.webthing_property.property = property_value
 
     def __convert(self, value):
-        source_type = self.openhab_item.type
-        target_type = self.webthing_property.type
+        source_type = self.openhab_item.metadata.type
+        target_type = self.webthing_property.metadata.type
         if source_type == 'switch':
             return value == 'ON'
         elif target_type == 'number':
@@ -98,21 +91,21 @@ class Link:
     def __init__(self, webthing_uri: str, webthing_property: str, openhab_uri: str, itemname: str):
         self.webthing_property = WebthingProperty(webthing_uri, webthing_property)
         self.openhab_item = OpenhabItem(openhab_uri, itemname)
-        if self.webthing_property.writeable:
-            print("Forward  Link openhab item " + self.openhab_item.itemname + " -> webthing property " + self.webthing_property.name + " created")
+        if self.webthing_property.metadata.readonly:
+            logging.info("Backward link openhab item " + self.openhab_item.metadata.name + " <- webthing property " + self.webthing_property.metadata.name + " created")
         else:
-            print("Backward link openhab item " + self.openhab_item.itemname + " <- webthing property " + self.webthing_property.name + " created")
+            logging.info("Forward  Link openhab item " + self.openhab_item.metadata.name + " -> webthing property " + self.webthing_property.metadata.name + " created")
 
     def start(self):
         threading.Thread(target=self.__listen).start()
 
     def __listen(self):
-        if self.webthing_property.writeable:
-            openhab_to_webthing_link = OpenhabItemToWebThingPropertyLink(self.webthing_property, self.openhab_item)
-            openhab_to_webthing_link.start()
-        else:
+        if self.webthing_property.metadata.readonly:
             webthing_to_openhab_link = WebThingPropertyToOpenhabItemLink(self.webthing_property, self.openhab_item)
             webthing_to_openhab_link.start()
+        else:
+            openhab_to_webthing_link = OpenhabItemToWebThingPropertyLink(self.webthing_property, self.openhab_item)
+            openhab_to_webthing_link.start()
 
         while True:
             time.sleep(10)
@@ -120,7 +113,7 @@ class Link:
 
 def run(filename: str):
     configs = load_config(filename)
-    print("config file " + filename + " loaded. " + str(len(configs)) + " entries found")
+    logging.info("config file " + filename + " loaded. " + str(len(configs)) + " entries found")
     for config in configs:
         Link(config.webthing_root_uri, config.webthing_property_name, config.openhab_root_uri, config.openhab_item_name).start()
 
